==> entodicton-5.51.98.tgz: package/client_test.js <==
const client = require('./client')
const Config = require('./src/config')

const url = 'http://entodicton/process'
const key = 'key123'

const objects = {}


describe('Client Tests', () => {
  describe('processContexts', () => {
    it('objects and semantics and generators', async () => {
      const initContext1 = { marker: 'this', value: 1, ranSemantics: [] }
      const initContext2 = { marker: 'this', value: 2, ranSemantics: [] }
      const objects = { property: 1, ranSemantics: [] }
      const semantics = [ [({context, global}) => context.marker === 'this', ({context, global}) => { 
        context.ranSemantics.push(context.value)
        global.ranSemantics.push(context.value)
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator ${context.value}`] ]
      const { contexts, generated } = client.processContexts([initContext1, initContext2], {semantics, generators, objects})
      expect(contexts[0].ranSemantics).toStrictEqual([1])
      expect(contexts[1].ranSemantics).toStrictEqual([2])
      expect(objects.ranSemantics).toStrictEqual([1,2])
      expect(generateds).toStrictEqual(['ran generator 1', 'ran generator 2'])
    });
  })

  describe('processContext', () => {
    it('objects and semantics and generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const objects = { property: 1 }
      const semantics = [ [({context, global}) => context.marker === 'this', ({context, global}) => { 
        context.ranSemantics = true 
        global.ranSemantics = true
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {semantics, generators, objects})
      expect(context.ranSemantics).toBe(true)
      expect(objects.ranSemantics).toBe(true)
      expect(generated).toBe('ran generator')
    });

    it('semantics and generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const semantics = [ [({context}) => context.marker === 'this', ({context}) => { 
        context.ranSemantics = true 
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {semantics, generators, objects})
      expect(context.ranSemantics).toBe(true)
      expect(generated).toBe('ran generator')
    });

    it('semantics', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const semantics = [ [({context}) => context.marker === 'this', ({context}) => { 
        context.ranSemantics = true 
      }] ]
      const { context, generated } = client.processContext(initContext, {semantics})
      expect(context.ranSemantics).toBe(true)
      expect(generated).toBe("{\"marker\":\"this\",\"value1\":1,\"ranSemantics\":true}")
    });

    it('generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {generators})
      expect(generated).toBe('ran generator')
    });
  });
  describe('process', () => {
  });
})

==> entodicton-5.51.116.tgz: package/client_test.js <==
const client = require('./client')
const Config = require('./src/config')

const url = 'http://entodicton/process'
const key = 'key123'

const objects = {}


describe('Client Tests', () => {
  describe('processContexts', () => {
    it('objects and semantics and generators', async () => {
      const initContext1 = { marker: 'this', value: 1, ranSemantics: [] }
      const initContext2 = { marker: 'this', value: 2, ranSemantics: [] }
      const objects = { property: 1, ranSemantics: [] }
      const semantics = [ [({context, objects}) => context.marker === 'this', ({context, objects}) => { 
        context.ranSemantics.push(context.value)
        objects.ranSemantics.push(context.value)
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator ${context.value}`] ]
      const { contexts, generated } = client.processContexts([initContext1, initContext2], {semantics, generators, objects})
      expect(contexts[0].ranSemantics).toStrictEqual([1])
      expect(contexts[1].ranSemantics).toStrictEqual([2])
      expect(objects.ranSemantics).toStrictEqual([1,2])
      expect(generateds).toStrictEqual(['ran generator 1', 'ran generator 2'])
    });
  })

  describe('processContext', () => {
    it('objects and semantics and generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const objects = { property: 1 }
      const semantics = [ [({context, objects}) => context.marker === 'this', ({context, objects}) => { 
        context.ranSemantics = true 
        objects.ranSemantics = true
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {semantics, generators, objects})
      expect(context.ranSemantics).toBe(true)
      expect(objects.ranSemantics).toBe(true)
      expect(generated).toBe('ran generator')
    });

    it('semantics and generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const semantics = [ [({context}) => context.marker === 'this', ({context}) => { 
        context.ranSemantics = true 
      }] ]
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {semantics, generators, objects})
      expect(context.ranSemantics).toBe(true)
      expect(generated).toBe('ran generator')
    });

    it('semantics', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const semantics = [ [({context}) => context.marker === 'this', ({context}) => { 
        context.ranSemantics = true 
      }] ]
      const { context, generated } = client.processContext(initContext, {semantics})
      expect(context.ranSemantics).toBe(true)
      expect(generated).toBe("{\"marker\":\"this\",\"value1\":1,\"ranSemantics\":true}")
    });

    it('generators', async () => {
      const initContext = { marker: 'this', value1: 1 }
      const generators = [ [({context}) => context.marker === 'this', ({context}) => `ran generator`] ]
      const { context, generated } = client.processContext(initContext, {generators})
      expect(generated).toBe('ran generator')
    });
  });
  describe('process', () => {
  });
})
